#!/usr/bin/env ruby
=begin

数式, テキストファイルから
おまかせで GPhys オブジェクトを作成する
ライブラリ gphys_io_utils.rb のデモです.

= 使い方

gphys_io_utils.rb をこのファイルと同じディレクトリに置いたうえで
以下のコマンドを実行します.

 $ ruby demo_gphys_io_util.rb description [options]

description:
以下のどれかに解釈されます,
* GPhys が扱えるバイナリファイル (.nc, .ctl, .grib)
* スペース, 改行区切りテキストファイル
* 数式
  * eval メソッドで Ruby に丸投げしています.
    NArray で実行できる関数なら何でも使えるはずです.
* ファイルパスとしても数式としても解釈できない (エラー)

option:
* --out: 絶対値が 1-4 の数字は描画の装置番号, 
          それ以外は出力先 netCDF ファイル.
          拡張子が .nc でない場合は自動的に '.nc' が補完される

== 例

 $ ruby demo_gphys_io_util.rb "x"
 $ ruby demo_gphys_io_util.rb "sin(x)"
 $ ruby demo_gphys_io_util.rb "x**2 + y**2"
 $ ruby demo_gphys_io_util.rb "sin(2*x*PI/10)*sin(y*PI/10)"
 $ ruby demo_gphys_io_util.rb "a=1; b=-10; c=25;  a*x**2+b*x+c" \
      --out "hoge.nc"
 $ ruby demo_gphys_io_util.rb "x*y*z"
 $ ruby demo_gphys_io_util.rb "x*y+z*w"

= 履歴

* 2012/02/08 Satoshi NODA  
* 2012/02/08 Satoshi NODA  --exe, --nout オプションの追加 
* 2012/02/07 Satoshi NODA  数式から GPhys への変換にオプションを追加
                           テキストデータから GPhys への変換を実装
* 2012/02/06 Satoshi NODA  数式から GPhys への変換を実装

=end


require 'numru/ggraph'
require 'optparse'
require 'gphys_io_util'
include NumRu
include NMath

# --------------------------------------------------

str = nil
out = 1

# commandline option
opt = OptionParser.new
opt.on('--out VAL') {|v| out = v }
opt.parse!(ARGV)

case ARGV.size
when 0 then
  puts "Usage: #{$0} str --out output"
  puts "    str:    path or equation(x,y,z,w)" 
  puts "    output: workstation number(1-4) or output netCDF filename(ex. hoge.nc)" 
  exit 0
#  p "demo"
#  p  str = "sin(2*x*PI/10)*sin(y*PI/10)"  # sample
when 1 then
  str = ARGV[0]
else
  raise "ERROR: invalid option: [#{ARGV.join(", ")}]"
end

if out.to_i.abs >= 1 and out.to_i.abs <= 4 then
  # quick view
  qv(str, out)
else
  # quick output
  qout(str, out)
end
